MethodChannelFlutterForegroundTask class

An implementation of FlutterForegroundTaskPlatform that uses method channels.

Inheritance

Properties

attachedActivity → Future<bool>
no setteroverride
canDrawOverlays → Future<bool>
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
isAppOnForeground → Future<bool>
no setteroverride
isIgnoringBatteryOptimizations → Future<bool>
no setteroverride
isRunningService → Future<bool>
no setteroverride
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkNotificationPermission() → Future<NotificationPermission>
override
launchApp([String? route]) → void
override
minimizeApp() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openIgnoreBatteryOptimizationSettings() → Future<bool>
override
openSystemAlertWindowSettings({bool forceOpen = false}) → Future<bool>
override
requestIgnoreBatteryOptimization() → Future<bool>
override
requestNotificationPermission() → Future<NotificationPermission>
override
restartService() → Future<ServiceRequestResult>
override
sendData(Object data) → void
override
setOnLockScreenVisibility(bool isVisible) → void
override
startService({required AndroidNotificationOptions androidNotificationOptions, required IOSNotificationOptions iosNotificationOptions, required ForegroundTaskOptions foregroundTaskOptions, required String notificationTitle, required String notificationText, NotificationIconData? notificationIcon, List<NotificationButton>? notificationButtons, Function? callback}) → Future<ServiceRequestResult>
override
stopService() → Future<ServiceRequestResult>
override
toString() → String
A string representation of this object.
inherited
updateService({ForegroundTaskOptions? foregroundTaskOptions, String? notificationTitle, String? notificationText, NotificationIconData? notificationIcon, List<NotificationButton>? notificationButtons, Function? callback}) → Future<ServiceRequestResult>
override
wakeUpScreen() → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited