ForegroundServiceTypes class
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Constants
-
camera
→ const ForegroundServiceTypes
-
Continue to access the camera from the background, such as video chat apps that allow for multitasking.
-
connectedDevice
→ const ForegroundServiceTypes
-
Interactions with external devices that require a Bluetooth, NFC, IR, USB, or network connection.
-
dataSync
→ const ForegroundServiceTypes
-
Data transfer operations, such as the following:
-
health
→ const ForegroundServiceTypes
-
Any long-running use cases to support apps in the fitness category such as exercise trackers.
-
location
→ const ForegroundServiceTypes
-
Long-running use cases that require location access, such as navigation and location sharing.
-
mediaPlayback
→ const ForegroundServiceTypes
-
Continue audio or video playback from the background. Support Digital Video Recording (DVR) functionality on Android TV.
-
mediaProcessing
→ const ForegroundServiceTypes
-
Service for performing time-consuming operations on media assets, like converting media to different formats.
-
mediaProjection
→ const ForegroundServiceTypes
-
Project content to non-primary display or external device using the MediaProjection APIs. This content doesn't have to be exclusively media content.
-
microphone
→ const ForegroundServiceTypes
-
Continue microphone capture from the background, such as voice recorders or communication apps.
-
phoneCall
→ const ForegroundServiceTypes
-
Continue an ongoing call using the ConnectionService APIs.
-
remoteMessaging
→ const ForegroundServiceTypes
-
Transfer text messages from one device to another. Assists with continuity of a user's messaging tasks when they switch devices.
-
shortService
→ const ForegroundServiceTypes
-
Quickly finish critical work that cannot be interrupted or postponed.
-
specialUse
→ const ForegroundServiceTypes
-
Covers any valid foreground service use cases that aren't covered by the other foreground service types.
-
systemExempted
→ const ForegroundServiceTypes
-
Reserved for system applications and specific system integrations, to continue to use foreground services.